@@ -78,6 +78,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import cdktf_cdktf_provider_google
@@ -101,6 +103,10 @@ class DockerVolumes:
         :param container_path: Job Runtime Container Path Host Path.
         :param host_path: EC2 Runner Host Path.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DockerVolumes.__init__)
+            check_type(argname="argument container_path", value=container_path, expected_type=type_hints["container_path"])
+            check_type(argname="argument host_path", value=host_path, expected_type=type_hints["host_path"])
         self._values: typing.Dict[str, typing.Any] = {
             "container_path": container_path,
             "host_path": host_path,
@@ -161,13 +167,13 @@ class GitlabRunnerAutoscaling(
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount] = None,
+        service_account: typing.Optional[typing.Union[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount, typing.Dict[str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -189,6 +195,10 @@ class GitlabRunnerAutoscaling(
         :param service_account: The Service Account to be used by the Gitlab Runner.
         :param tags: tags for the runner. Default: - ['runner', 'gitlab', 'awscdk']
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabRunnerAutoscaling.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabRunnerAutoscalingProps(
             gitlab_token=gitlab_token,
             provider=provider,
@@ -220,13 +230,13 @@ class GitlabRunnerAutoscaling(
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount] = None,
+        service_account: typing.Optional[typing.Union[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount, typing.Dict[str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> typing.List[builtins.str]:
         '''
@@ -301,13 +311,13 @@ class GitlabRunnerAutoscalingProps:
         concurrent: typing.Optional[jsii.Number] = None,
         default_disk_size_gb: typing.Optional[jsii.Number] = None,
         desired_capacity: typing.Optional[jsii.Number] = None,
-        docker_volumes: typing.Optional[typing.Sequence[DockerVolumes]] = None,
+        docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
         download_gitlab_runner_binary_url: typing.Optional[builtins.str] = None,
         gitlab_url: typing.Optional[builtins.str] = None,
         machine_type: typing.Optional[builtins.str] = None,
         network_tags: typing.Optional[typing.Sequence[builtins.str]] = None,
         preemptible: typing.Optional[builtins.bool] = None,
-        service_account: typing.Optional[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount] = None,
+        service_account: typing.Optional[typing.Union[cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount, typing.Dict[str, typing.Any]]] = None,
         tags: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -329,6 +339,23 @@ class GitlabRunnerAutoscalingProps:
         '''
         if isinstance(service_account, dict):
             service_account = cdktf_cdktf_provider_google.ComputeInstanceTemplateServiceAccount(**service_account)
+        if __debug__:
+            type_hints = typing.get_type_hints(GitlabRunnerAutoscalingProps.__init__)
+            check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
+            check_type(argname="argument automatic_restart", value=automatic_restart, expected_type=type_hints["automatic_restart"])
+            check_type(argname="argument compute_network", value=compute_network, expected_type=type_hints["compute_network"])
+            check_type(argname="argument concurrent", value=concurrent, expected_type=type_hints["concurrent"])
+            check_type(argname="argument default_disk_size_gb", value=default_disk_size_gb, expected_type=type_hints["default_disk_size_gb"])
+            check_type(argname="argument desired_capacity", value=desired_capacity, expected_type=type_hints["desired_capacity"])
+            check_type(argname="argument docker_volumes", value=docker_volumes, expected_type=type_hints["docker_volumes"])
+            check_type(argname="argument download_gitlab_runner_binary_url", value=download_gitlab_runner_binary_url, expected_type=type_hints["download_gitlab_runner_binary_url"])
+            check_type(argname="argument gitlab_url", value=gitlab_url, expected_type=type_hints["gitlab_url"])
+            check_type(argname="argument machine_type", value=machine_type, expected_type=type_hints["machine_type"])
+            check_type(argname="argument network_tags", value=network_tags, expected_type=type_hints["network_tags"])
+            check_type(argname="argument preemptible", value=preemptible, expected_type=type_hints["preemptible"])
+            check_type(argname="argument service_account", value=service_account, expected_type=type_hints["service_account"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "gitlab_token": gitlab_token,
             "provider": provider,
